#!/usr/bin/env python

###
# Copyright (c) 2002-2004, Jeremiah Fincher
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions, and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions, and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the author of this software nor the name of
#     contributors to this software may be used to endorse or promote products
#     derived from this software without specific prior written consent.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
###

from testsupport import *

import re
import supybot.ircmsgs as ircmsgs

import supybot.utils as utils

class FunTest(ChannelPluginTestCase, PluginDocumentation):
    plugins = ('Fun',)
    _nonKickRe = re.compile(r'bang|click|spin', re.I)
    def testRoulette(self):
        self.irc.feedMsg(ircmsgs.op(self.channel, self.irc.nick))
        sawKick = False
        for i in xrange(100):
            m = self.getMsg('roulette', frm='someoneElse')
            if m.command == 'PRIVMSG':
                self.failUnless(self._nonKickRe.search(m.args[1]),
                                'Got a PRIVMSG without bang|click|spin in it.')
            elif m.command == 'KICK':
                sawKick = True
                self.failUnless('bang' in m.args[2].lower(),
                                'Got a KICK without bang in it.')
            else:
                self.fail('Got something other than a kick or a privmsg.')
        self.failUnless(sawKick, 'Didn\'t get a kick in %s iterations!' % i)

    def testPing(self):
        self.assertResponse('ping', 'pong')

    def testEightball(self):
        self.assertNotError('eightball')
        self.assertNotError('eightball a')
        self.assertNotError('eightball ab')
        self.assertNotError('eightball abc')

    def testNoErrors(self):
        self.assertNotError('objects')
        self.assertNotError('levenshtein Python Perl')

    def testSoundex(self):
        self.assertNotError('soundex jemfinch')
        self.assertNotRegexp('soundex foobar 3:30', 'ValueError')

    def testChr(self):
        for i in range(256):
            c = chr(i)
            regexp = r'%s|%s' % (re.escape(c), re.escape(repr(c)))
            self.assertRegexp('chr %s' % i, regexp)

    def testXor(self):
        L = [nick for nick in nicks if '|' not in nick and
                                       '[' not in nick and
                                       ']' not in nick]
        for s0, s1, s2, s3, s4, s5, s6, s7, s8, s9 in group(L, 10):
            data = '%s%s%s%s%s%s%s%s%s' % (s0, s1, s2, s3, s4, s5, s6, s7, s8)
            self.assertResponse('xor %s [xor %s %s]' % (s9, s9, data), data)

    def testUrlquoteUrlunquote(self):
        self.assertResponse('urlunquote [urlquote ~jfincher]', '~jfincher')

    def testOrd(self):
        for c in map(chr, range(256)):
            i = ord(c)
            self.assertResponse('ord %s' % utils.dqrepr(c), str(i))

    def testEncodeDecode(self):
        s = 'the recalcitrant jamessan tests his scramble function'
        self.assertNotRegexp('encode aldkfja foobar', 'LookupError')
        self.assertNotRegexp('decode asdflkj foobar', 'LookupError')
        self.assertResponse('decode zlib [encode zlib %s]' % s, s)

# vim:set shiftwidth=4 tabstop=8 expandtab textwidth=78:
